ledger.Account (Account) — amici1

# `ledger.Account` (Account)

Account(id, ref, seqno, name, common_account, needs_partner, clearable, default_amount, name_de, name_fr)

Master tables : ledger.Accounts (Accounts), ledger.GeneralAccountBalances (General Account Balances)

Slave tables : ledger.MatchRulesByAccount (Match rules), ledger.MovementsByAccount (Movements)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : An optional unique name which can be used to reference a given account.

- No. (seqno) : The sequence number of this item with its parent.

- Designation (name) : The multilingual designation of this account, as the users see it.

- Common account (common_account) : See `<lino.core.choicelists.ChoiceListField: common_account>`.

- Needs partner (needs_partner) : Whether bookings to this account need a partner specified.

- Clearable (clearable) : See `<django.db.models.fields.BooleanField: clearable>`.

- Default amount (default_amount) : The default amount to book in bank statements or journal entries when this account has been selected manually. The default booking direction is that of the type.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Sales (sales_allowed) : Whether this account is available for Sales transactions.

- Purchases (purchases_allowed) : Whether this account is available for Purchases transactions.

- Wages (wages_allowed) : Whether this account is available for Wages transactions.

- Taxes (taxes_allowed) : Whether this account is available for Taxes transactions.

- Clearings (clearings_allowed) : Whether this account is available for Clearings transactions.

- Bank payment orders (bank_po_allowed) : Whether this account is available for Bank payment orders transactions.

- Description (description) : See `lino_xl.lib.ledger.models.Account.description`.

- Name (name_column) : See `lino_xl.lib.ledger.models.Account.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.Account.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.Account.overview`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

Referenced from ledger.Journal.account, ledger.MatchRule.account, ledger.Movement.account

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | An optional unique name which can be used to reference a given account.
seqno | No. | The sequence number of this item with its parent.
name | Designation | The multilingual designation of this account, as the users see it.
common_account | Common account |
needs_partner | Needs partner | Whether bookings to this account need a partner specified.
clearable | Clearable |
default_amount | Default amount | The default amount to book in bank statements or journal entries when this account has been selected manually. The default booking direction is that of the type.
name_de | Designation (de) |
name_fr | Designation (fr) |
sales_allowed | Sales | Whether this account is available for Sales transactions.
purchases_allowed | Purchases | Whether this account is available for Purchases transactions.
wages_allowed | Wages | Whether this account is available for Wages transactions.
taxes_allowed | Taxes | Whether this account is available for Taxes transactions.
clearings_allowed | Clearings | Whether this account is available for Clearings transactions.
bank_po_allowed | Bank payment orders | Whether this account is available for Bank payment orders transactions.
description | Description |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
move_buttons | Move | Displays buttons for certain actions on this row: